@@ -13,7 +13,8 @@ import sys
 from pathlib import Path
 from typing import Iterator, Optional
 
-from kraken.core.utils import not_none
+from kraken.core.util.helpers import not_none
+from kraken.core.util.krakenw import KrakenwEnv
 from proxy.http.parser import HttpParser
 from proxy.http.proxy.plugin import HttpProxyBasePlugin
 
@@ -38,6 +39,10 @@ class AuthInjector(HttpProxyBasePlugin):
         # NOTE (@NiklasRosenstein): This method is only called for requests in an HTTPS tunnel if TLS
         #       interception is enabled, which requires a self-signed CA-certificate.
 
+        if not request.method or not request.headers:
+            return request
+
+        method = request.method.decode()
         host = not_none(request.headers)[b"host"][1].partition(b":")[0].decode()
         # path = request.path.decode() if request.path else None
 
@@ -47,7 +52,7 @@ class AuthInjector(HttpProxyBasePlugin):
         #     new_url = f'https://{host}{path}'
         #     request.set_url(new_url.encode())
 
-        if host in self.auth and not request.has_header(b"Authorization"):
+        if method != "CONNECT" and host in self.auth and not request.has_header(b"Authorization"):
             logger.info("injecting Authorization for %s request to %s", not_none(request.method).decode(), host)
             creds = self.auth[host]
             auth = base64.b64encode(f"{creds[0]}:{creds[1]}".encode())
@@ -60,17 +65,25 @@ class AuthInjector(HttpProxyBasePlugin):
 def mitm_auth_proxy(
     auth: dict[str, tuple[str, str]],
     port: int = 8899,
+    timeout: float | None = None,
 ) -> Iterator[tuple[str, Path]]:
     """Runs a MITM HTTPS proxy that injects credentials according to *auth* into requests."""
 
+    if timeout is None and "PROXY_PY_TIMEOUT" in os.environ:
+        timeout = int(os.environ["PROXY_PY_TIMEOUT"])
+
     certs_dir = Path(__file__).parent / "data" / "certs"
     key_file = certs_dir / "key.pem"
     cert_file = certs_dir / "cert.pem"
 
-    command = [
-        sys.executable,
-        "-m",
-        "proxy",
+    env = os.environ.copy()
+    kwenv = KrakenwEnv.get()
+    if kwenv and kwenv.is_pex:
+        env["PEX_SCRIPT"] = "proxy"
+        command = [str(kwenv.path)]
+    else:
+        command = [sys.executable, "-m", "proxy"]
+    command += [
         "--plugins",
         __name__ + "." + AuthInjector.__name__,
         "--ca-key-file",
@@ -83,16 +96,14 @@ def mitm_auth_proxy(
         str(port),
     ]
 
-    env = os.environ.copy()
-    env["INJECT_AUTH"] = json.dumps(auth)
+    if timeout is not None:
+        command += ["--timeout", str(timeout)]
 
-    if os.getenv("KRAKEN_CARGO_MITM_DEBUG") in ("1", "true"):
-        stdout, stderr = None, None
-    else:
-        stdout, stderr = sp.DEVNULL, sp.DEVNULL
+    env["INJECT_AUTH"] = json.dumps(auth)
+    env["PYTHONWARNINGS"] = "ignore"
 
     logger.info("starting proxy server: %s", command)
-    proc = sp.Popen(command, env=env, stdout=stdout, stderr=stderr)
+    proc = sp.Popen(command, env=env)
 
     try:
         yield f"http://localhost:{port}", cert_file
