@@ -1,18 +1,21 @@
 from __future__ import annotations
 
-import subprocess as sp
-from typing import Optional
+from typing import Dict, List, Optional
 
-from kraken.core import Property, Task, TaskStatus
+from kraken.core import Property
+
+from .cargo_build_task import CargoBuildTask
 
 
-class CargoClippyTask(Task):
+class CargoClippyTask(CargoBuildTask):
     """Runs `cargo clippy` for linting or applying suggestions."""
 
     fix: Property[bool] = Property.default(False)
     allow: Property[Optional[str]] = Property.default("staged")
 
-    def execute(self) -> TaskStatus | None:
+    # CargoBuildTask
+
+    def get_cargo_command(self, env: Dict[str, str]) -> List[str]:
         command = ["cargo", "clippy"]
         if self.fix.get():
             command += ["--fix"]
@@ -20,7 +23,7 @@ class CargoClippyTask(Task):
             if allow == "staged":
                 command += ["--allow-staged"]
             elif allow == "dirty":
-                command += ["--allow-dirty"]
+                command += ["--allow-dirty", "--allow-staged"]
             elif allow is not None:
                 raise ValueError(f"invalid allow: {allow!r}")
-        return TaskStatus.from_exit_code(command, sp.call(command, cwd=self.project.directory))
+        return command
