@@ -3,9 +3,12 @@ from __future__ import annotations
 import os
 import re
 import subprocess as sp
+from pathlib import Path
 
-from kraken.core.task import TaskStatus
-from kraken.core.utils import flatten, not_none
+from kraken.core import Project, TaskStatus
+from kraken.core.util.helpers import flatten, not_none
+
+from kraken.std.docker.util import update_run_commands
 
 from . import DockerBuildTask
 
@@ -13,6 +16,18 @@ from . import DockerBuildTask
 class BuildxBuildTask(DockerBuildTask):
     """Implements building a Docker image with Buildx."""
 
+    def __init__(self, name: str, project: Project) -> None:
+        super().__init__(name, project)
+        self.preprocess_dockerfile.set(True)
+
+    # DockerBuildTask
+
+    def _preprocess_dockerfile(self, dockerfile: Path) -> str:
+        mount_string = " ".join(f"--mount=type=secret,id={sec}" for sec in self.secrets.get().keys()) + " "
+        return update_run_commands(dockerfile.read_text(), prefix=mount_string)
+
+    # Task
+
     def finalize(self) -> None:
         if not self.load.get() and not self.push.get():
             self.logger.info("activating --load because one of --load or --push is necessary with Buildx")
@@ -37,6 +52,7 @@ class BuildxBuildTask(DockerBuildTask):
         if self.cache_repo.get():
             # NOTE (@NiklasRosenstein): Buildx does not allow leading underscores, while Kaniko and Artifactory do.
             command += ["--cache-to", f"type=registry,ref={not_none(self.cache_repo.get())}"]
+            command += ["--cache-from", f"type=registry,ref={not_none(self.cache_repo.get())}"]
         if not self.cache.get():
             command += ["--no-cache"]
         command += flatten(["--tag", t] for t in self.tags.get())
