@@ -8,7 +8,9 @@ from pathlib import Path
 from kraken.core.project import Project
 from kraken.core.property import Property
 from kraken.core.task import TaskStatus
-from kraken.core.utils import flatten, not_none
+from kraken.core.util.helpers import flatten, not_none
+
+from kraken.std.docker.util import update_run_commands
 
 from . import DockerBuildTask
 
@@ -17,11 +19,19 @@ class NativeBuildTask(DockerBuildTask):
     """Implements building a Docker image using the native `docker build` command."""
 
     #: Whether to use Docker Buildkit. Enabled by default.
-    native_use_buildkit: Property[bool]
+    native_use_buildkit: Property[bool] = Property.default(True)
 
     def __init__(self, name: str, project: Project) -> None:
         super().__init__(name, project)
-        self.native_use_buildkit.set(True)
+        self.preprocess_dockerfile.set(True)
+
+    # DockerBuildTask
+
+    def _preprocess_dockerfile(self, dockerfile: Path) -> str:
+        mount_string = " ".join(f"--mount=type=secret,id={sec}" for sec in self.secrets.get().keys()) + " "
+        return update_run_commands(dockerfile.read_text(), prefix=mount_string)
+
+    # Task
 
     def finalize(self) -> None:
         if self.cache_repo.get() is not None:
@@ -52,6 +62,8 @@ class NativeBuildTask(DockerBuildTask):
         if self.image_output_file.get():
             command += ["--output", f"type=tar,dest={self.image_output_file.get()}"]
 
+        command += ["--progress", "plain"]
+
         # Buildx will take the secret from the environment variasbles.
         env = os.environ.copy()
         env["DOCKER_BUILDKIT"] = "1" if self.native_use_buildkit.get() else "0"
