@@ -15,7 +15,7 @@ class IsortTask(EnvironmentAwareDispatchTask):
     additional_files: Property[List[Path]] = Property.config(default_factory=list)
 
     def get_execute_command(self) -> list[str]:
-        command = ["isort", "src/"] + self.settings.get_tests_directory_as_args()
+        command = ["isort", str(self.settings.source_directory)] + self.settings.get_tests_directory_as_args()
         command += [str(p) for p in self.additional_files.get()]
         if self.check_only.get():
             command += ["--check-only"]
@@ -23,6 +23,14 @@ class IsortTask(EnvironmentAwareDispatchTask):
             command += ["--settings-file", str(self.config_file.get())]
         return command
 
+    # Task
+
+    def get_description(self) -> str | None:
+        if self.check_only.get():
+            return "Check Python source files formatting with isort."
+        else:
+            return "Format Python source files with isort."
+
 
 @dataclasses.dataclass
 class IsortTasks:
